Struct ZwpVirtualKeyboardManagerV1
pub struct ZwpVirtualKeyboardManagerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
virtual keyboard manager
A virtual keyboard manager allows an application to provide keyboard input events as if they came from a physical keyboard.
This interface has no events.
Implementations
impl ZwpVirtualKeyboardManagerV1
impl ZwpVirtualKeyboardManagerV1
pub fn create_virtual_keyboard<U, D>(
&self,
seat: &WlSeat,
qh: &QueueHandle<D>,
udata: U,
) -> ZwpVirtualKeyboardV1
pub fn create_virtual_keyboard<U, D>( &self, seat: &WlSeat, qh: &QueueHandle<D>, udata: U, ) -> ZwpVirtualKeyboardV1
Create a new virtual keyboard
Creates a new virtual keyboard associated to a seat.
If the compositor enables a keyboard to perform arbitrary actions, it should present an error when an untrusted client requests a new keyboard.